# 功能：发布光线数据
# 实验：这个实验需要2个掌控板，一个发布光线数据一个订阅光线数据
#           发布的掌控板，给光线传感器不同的光照，光线强度将被发布到
#           OneNet的对应主题，供其他设备使用
#注意事项：这个实验需要2个掌控板，这是发布端代码
#     本实验使用的是OneNet物联网，用户需要注册OneNet账号，添加
#     产品和设备，并将产品设备信息更新到这个示例中      

from mpython import light
from Iot import Iot
from umqttsimple import MQTTClient
import machine
import time
import json
import network

WIFI_SSID = 'yourSSID'#替换成你的WIFI热点名称
WIFI_PASSWORD = 'yourPASSWD'#替换成你的WIFI热点密码

ONENET_SERVER = "mqtt.heclouds.com"
ONENET_PORT = 6002
ProductID = "your ProductID"#替换成你的OneNet产品ID
DeviceId = "your DeviceId"#替换成你的OneNet设备ID
ApiKey = "your ApiKey"#替换成你的OneNet设备ApiKey

pubTopic = 'light'

def connectWIFI():
  station = network.WLAN(network.STA_IF)
  station.active(True)
  station.connect(WIFI_SSID,WIFI_PASSWORD)
  while station.isconnected() == False:
    pass
  print('Connection successful')
  print(station.ifconfig())
  
def restart():
  time.sleep(10)
  machine.reset()
  
connectWIFI()
myIot = Iot(ONENET_SERVER, ProductID, DeviceId, ApiKey)
client = MQTTClient(myIot.client_id, myIot.mqttserver, port = ONENET_PORT, user = myIot.username, password = myIot.password)
client.connect()
timeLimit = 2#10s
lastTime = 0
msg = {}
while True:
  try:
    client.check_msg()
    if(time.time() - lastTime) > timeLimit:
      msg["light"] = light.read()
      print(json.dumps(msg))
      client.publish(pubTopic,json.dumps(msg))
      lastTime = time.time()
  except OSError as e:
    restart()